import java.io.*;
import java.net.*;

public class Connection {
  private String tcpHost = "192.168.1.51";
  private int tcpPort = 4321;
  private BufferedWriter out;
  private BufferedReader in;
  private OnMessageReceived messageListener = null;
  private boolean mRun = false;
  private String clientMessage = null;
  Socket socket = null;

  public Connection(OnMessageReceived listener) {
    messageListener = listener;
    beginConnection();
  }

  public Connection(String host, String port, OnMessageReceived listener) {
    tcpHost = host;
    try {
      tcpPort = Integer.parseInt(port);
    } 
    catch (NumberFormatException e) {
      // keep default port number
    }
    messageListener = listener;
    beginConnection();
  }

  private void beginConnection() {
    try {
      // here you must put your computer's IP address.
      InetAddress serverAddr = InetAddress.getByName(tcpHost);
      // create a socket to make the connection with the server
      socket = new Socket(serverAddr, tcpPort);
      socket.setSoTimeout(100);
      // create output stream to send messages to the server
      out = new BufferedWriter(new OutputStreamWriter(socket.getOutputStream()));
      // create input stream to receive messages from server
      in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
    }
    catch (Exception e) {
    }
  }

  public void receiveMessage() {
    String serverMessage;

    try {
      serverMessage = in.readLine();
    } 
    catch (IOException e) {
      serverMessage = null;
    }
    if (serverMessage != null) {
      if (messageListener != null) {
        // call the method messageReceived from MyActivity
        messageListener.messageReceived(serverMessage);
      }
    }
  }

  /**
   * Sends the message entered by client to the server
   * 
   * @param message
   *            text entered by client
   */
  public void sendMessage(String msg) {
    try {
      out.write(msg);
      out.flush();
    } 
    catch (IOException e) {
    }
    delay(10);
  }  

  public void stopConnection() {
    // the socket and associated streams must be closed.
    if (out != null) {
      try {
        out.flush();
        out.close();
      } 
      catch (IOException e) {
      }
    } 
    if (in != null) {
      try {
        in.close();
      } 
      catch (IOException e) {
      }
    }
    if (socket != null) {
      try {
        socket.close();
      } 
      catch (IOException e) {
      }
    }
  }
}

